==> ordered_set-1.0.0.tar.gz: README.md <==
# ordered_set

[![Build Status](https://travis-ci.org/luanpotter/ordered_set.svg?branch=master)](https://travis-ci.org/luanpotter/ordered_set)
[![Coverage Status](https://coveralls.io/repos/github/luanpotter/ordered_set/badge.svg?branch=master)](https://coveralls.io/github/luanpotter/ordered_set?branch=master)

A simple implementation for an ordered set for Dart.

It accepts a compare function that compares items for their priority.

Unlike Dart's [SplayTreeSet](https://api.dartlang.org/stable/1.24.3/dart-collection/SplayTreeSet/SplayTreeSet.html), it allows for several different elements with the same priority to be added.

It also implements [Iterable](https://api.dartlang.org/stable/1.24.3/dart-core/Iterable-class.html), so you can iterate it in O(n).

## Usage

A simple usage example:

```dart
  import 'package:ordered_set/ordered_set.dart';

  main() {
    OrderedSet<int> items = new OrderedSet();
    items.add(2);
    items.add(1);
    print(items.toList()); // [1, 2]
  }
```

## Comparing

In order to assist the creation of OrderedSet's, there is a Comparing class to easily create Comparables:

```dart
  // sort by name length
  final people = new OrderedSet<Person>(Comparing.on((p) => p.name.length));

  // sort by name desc
  final people = new OrderedSet<Person>(Comparing.reverse(Comparing.on((p) => p.name)));

  // sort by role and then by name
  final people = new OrderedSet<Person>(Comparing.join([(p) => p.role, (p) => p.name]));
```

## Contributing

All contributions are very welcome! Please feel free to create Issues, help us with PR's or comment your suggestions, feature requests, bugs, et cetera. Give us a star if you liked it!

==> ordered_set-1.1.5.tar.gz: README.md <==
# ordered_set

[![Build Status](https://travis-ci.org/luanpotter/ordered_set.svg?branch=master)](https://travis-ci.org/luanpotter/ordered_set)
[![Coverage Status](https://coveralls.io/repos/github/luanpotter/ordered_set/badge.svg?branch=master)](https://coveralls.io/github/luanpotter/ordered_set?branch=master)

A simple implementation for an ordered set for Dart.

It accepts a compare function that compares items for their priority.

Unlike Dart's [SplayTreeSet](https://api.dartlang.org/stable/1.24.3/dart-collection/SplayTreeSet/SplayTreeSet.html), it allows for several different elements with the same priority to be added.

It also implements [Iterable](https://api.dartlang.org/stable/1.24.3/dart-core/Iterable-class.html), so you can iterate it in O(n).

## Usage

A simple usage example:

```dart
  import 'package:ordered_set/ordered_set.dart';

  main() {
    OrderedSet<int> items = OrderedSet();
    items.add(2);
    items.add(1);
    print(items.toList()); // [1, 2]
  }
```

## Comparing

In order to assist the creation of OrderedSet's, there is a Comparing class to easily create Comparables:

```dart
  // sort by name length
  final people = OrderedSet<Person>(Comparing.on((p) => p.name.length));

  // sort by name desc
  final people = OrderedSet<Person>(Comparing.reverse(Comparing.on((p) => p.name)));

  // sort by role and then by name
  final people = OrderedSet<Person>(Comparing.join([(p) => p.role, (p) => p.name]));
```

## Contributing

All contributions are very welcome! Please feel free to create Issues, help us with PR's or comment your suggestions, feature requests, bugs, et cetera. Give us a star if you liked it!
